import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  axisLeft,
  axisBottom,
  extent,
  format
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const title = 'Agriculture - Fertility relationship';
  
  const xValue = d => d.Agriculture;
  const xAxisLabel = 'Percent of males in agriculture';
  
  const yValue = d => d.Fertility;
  const yAxisLabel = 'Standard fertility measure';
  
  const margin = {top: 55, right: 20, bottom: 60, left: 90};
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
	
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue).reverse())
  	.range([0, innerHeight])
  	.nice();
  
  const formatNumber = number =>
  	format('.0%')(number/100)
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(formatNumber)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  
	const yAxis = axisLeft(yScale)
  	.tickFormat(formatNumber)
  	.tickSize(-innerWidth)
  	.tickPadding(8);
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  xAxisG.
  	selectAll('.domain').remove();
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.
  	selectAll('.domain').remove();
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('cx', d => xScale(xValue(d)))
  	.attr('r', 10);
  
  g.append('text')
  	.attr('y', -25)
  	.text(title);
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth / 2)
  	.attr('y', 48)
  	.text(xAxisLabel);
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', -innerHeight / 2)
  	.attr('text-anchor', 'middle')
  	.attr('y', -55)
  	.text(yAxisLabel)
  	.attr('transform', `rotate(-90)`);
}

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.Agriculture = +d.Agriculture;
    d.Catholic = +d.Catholic;
    d.Education = +d.Education;
    d.Examination = +d.Examination;
    d.Fertility = +d.Fertility;
    d.InfantMortality = +d.InfantMortality;
  });
	render(data);
});




































